import { z } from 'zod';

// 同意请求验证模式
export const consentRequestSchema = z.object({
    client_id: z.string(),
    redirect_uri: z.string().url(),
    state: z.string().optional(),
    scope: z.string().optional().default('openid profile email'),
    response_type: z.union([
        z.literal('code'),                 // 授权码流程
        z.literal('token'),                // 隐式流程 - 仅访问令牌
        z.literal('id_token'),             // 隐式流程 - 仅ID令牌
        z.literal('token id_token'),       // 隐式流程 - 访问令牌和ID令牌
        z.literal('code id_token'),        // 混合流程 - 授权码和ID令牌
        z.literal('code token'),           // 混合流程 - 授权码和访问令牌
        z.literal('code token id_token'),  // 混合流程 - 授权码、访问令牌和ID令牌
    ]).default('code'),
    response_mode: z.enum(['query', 'fragment', 'form_post']).optional().default('query'),
    nonce: z.string().optional(),
    code_challenge: z.string().optional(),
    code_challenge_method: z.enum(['plain', 'S256']).optional().default('plain'),
});

// 同意表单验证模式
export const consentFormSchema = z.object({
    client_id: z.string(),
    redirect_uri: z.string().url(),
    state: z.string().optional(),
    scope: z.string(),
    allow: z.boolean(),
    response_type: z.union([
        z.literal('code'),                 // 授权码流程
        z.literal('token'),                // 隐式流程 - 仅访问令牌
        z.literal('id_token'),             // 隐式流程 - 仅ID令牌
        z.literal('token id_token'),       // 隐式流程 - 访问令牌和ID令牌
        z.literal('code id_token'),        // 混合流程 - 授权码和ID令牌
        z.literal('code token'),           // 混合流程 - 授权码和访问令牌
        z.literal('code token id_token'),  // 混合流程 - 授权码、访问令牌和ID令牌
    ]).default('code'),
    response_mode: z.enum(['query', 'fragment', 'form_post']).optional().default('query'),
    nonce: z.string().optional(),
    code_challenge: z.string().optional(),
    code_challenge_method: z.enum(['plain', 'S256']).optional().default('plain'),
});

// 类型定义
export type ConsentRequest = z.infer<typeof consentRequestSchema>;
export type ConsentForm = z.infer<typeof consentFormSchema>; 